.. -*- rst -*- -*- restructuredtext -*-
.. This file should be written using restructured text conventions

Salem
=====

.. image:: https://travis-ci.org/fmaussion/salem.svg?branch=master
    :target: https://travis-ci.org/fmaussion/salem
.. image:: https://coveralls.io/repos/fmaussion/salem/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/fmaussion/salem?branch=master
.. image:: https://readthedocs.org/projects/salem/badge/?version=latest
  :target: http://salem.readthedocs.io/en/latest/?badge=latest
.. image:: https://zenodo.org/badge/42607422.svg
   :target: https://zenodo.org/badge/latestdoi/42607422


Salem is a `cat`_. Salem is also a small library to do some geoscientific data
processing and plotting. It extends `xarray`_ to add geolocalised
subsetting, masking, and plotting operations to xarray's `DataArray`_ and
`DataSet`_ structures.

.. _cat: https://drive.google.com/file/d/0B-0AsTwFw61uSE0zaktOOVN5X1E/view?usp=sharing
.. _xarray: http://xarray.pydata.org/en/stable/
.. _DataArray: http://xarray.pydata.org/en/stable/data-structures.html#dataarray
.. _DataSet: http://xarray.pydata.org/en/stable/data-structures.html#dataset

Documentation
-------------

A draft of documentation is hosted on ReadTheDocs: http://salem.readthedocs.io

License
-------

Salem is available under the open source `GNU GPLv3 license`_.

.. _GNU GPLv3 license: http://www.gnu.org/licenses/gpl-3.0.en.html

About
-----

:Status:
    Experimental - in development

:License:
    GNU GPLv3

:Authors:
    `Fabien Maussion <http://fabienmaussion.info/>`_

:Funding:
    .. image:: http://acinn.uibk.ac.at/sites/all/themes/imgi/images/acinn_logo.png
